==> haskell-lsp-test-0.15.0.1-39-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp-test
version:              0.15.0.1
visibility:           public
id:                   lsp-test-0.15.0.1-BGEj1b5aDdg5k2rLtas9eE
key:                  lsp-test-0.15.0.1-BGEj1b5aDdg5k2rLtas9eE
license:              BSD-3-Clause
copyright:            2021 Luke Lau
maintainer:           luke_lau@icloud.com
author:               Luke Lau
homepage:
    https://github.com/haskell/lsp/blob/master/lsp-test/README.md

synopsis:             Functional test framework for LSP servers.
description:
    A test framework for writing tests against
    <https://microsoft.github.io/language-server-protocol/ Language Server Protocol servers>.
    @Language.LSP.Test@ launches your server as a subprocess and allows you to simulate a session
    down to the wire.
    To see examples of it in action, check out <https://github.com/haskell/haskell-ide-engine haskell-ide-engine>,
    <https://github.com/haskell/haskell-language-server haskell-language-server> and
    <https://github.com/digital-asset/ghcide ghcide>.

category:             Testing
abi:                  6032465a671b19fe1418e1a8d2852950
exposed:              True
exposed-modules:
    Control.Applicative.Combinators from parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav:Control.Applicative.Combinators,
    Language.LSP.Protocol.Capabilities from lsp-types-2.0.1.0-11kcCUIWM0n8rW3sZUJHGA:Language.LSP.Protocol.Capabilities,
    Language.LSP.Protocol.Message from lsp-types-2.0.1.0-11kcCUIWM0n8rW3sZUJHGA:Language.LSP.Protocol.Message,
    Language.LSP.Protocol.Types from lsp-types-2.0.1.0-11kcCUIWM0n8rW3sZUJHGA:Language.LSP.Protocol.Types,
    Language.LSP.Test

hidden-modules:
    Language.LSP.Test.Compat Language.LSP.Test.Decoding
    Language.LSP.Test.Exceptions Language.LSP.Test.Files
    Language.LSP.Test.Parsing Language.LSP.Test.Server
    Language.LSP.Test.Session

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lsp-test-0.15.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lsp-test-0.15.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lsp-test-0.15.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp-test
hs-libraries:         HSlsp-test-0.15.0.1-BGEj1b5aDdg5k2rLtas9eE
depends:
    Diff-0.5-2Up5HNAxZSNmr3b9Y21Rq Glob-0.10.2-3QVYkf3SaJR6RNS9OX3HgD
    aeson-2.1.2.1-6FuMYI3vdPa8Ts5NPsnpCg
    aeson-pretty-0.8.10-FQa8xIJIIpZJMrtrbu8IN4
    ansi-terminal-1.0.2-K3FcB9OuSW9G9IWrQwwwo4
    async-2.2.5-DWviBtrYTc7K8qRxzPsJC base-4.17.2.1 bytestring-0.11.5.3
    co-log-core-0.3.2.5-4V3HmgoGkXErp4Ib9Tvbp
    conduit-1.3.6.1-E440ekNNgW6K3EfLZREfa1
    conduit-parse-0.2.1.1-9MidOXVTinWCq8yyl0NeYy containers-0.6.7
    data-default-0.7.1.2-7bG7braRZax6ZJaJ3dSesR directory-1.3.7.1
    exceptions-0.10.5 filepath-1.4.2.2
    lens-5.3.1-57CGCDOUfQCLkJSlnZcVUR
    lsp-2.1.0.0-GxokUjVxBLy4j05JlhgdFg
    lsp-types-2.0.1.0-11kcCUIWM0n8rW3sZUJHGA mtl-2.2.2
    parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav process-1.6.18.0
    row-types-1.0.1.2-FQkLZYizLy6IrD2AIWrDwp
    some-1.0.6-BgHjEa55QMN2vvDsEzMV1h text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unix-2.7.3

haddock-interfaces:   /usr/share/doc/haskell-lsp-test/html/lsp-test.haddock
haddock-html:         /usr/share/doc/haskell-lsp-test/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lsp-test-0.15.0.1-63-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp-test
version:              0.15.0.1
visibility:           public
id:                   lsp-test-0.15.0.1-6xbEqv855SH8gUFKA5jj3l
key:                  lsp-test-0.15.0.1-6xbEqv855SH8gUFKA5jj3l
license:              BSD-3-Clause
copyright:            2021 Luke Lau
maintainer:           luke_lau@icloud.com
author:               Luke Lau
homepage:
    https://github.com/haskell/lsp/blob/master/lsp-test/README.md

synopsis:             Functional test framework for LSP servers.
description:
    A test framework for writing tests against
    <https://microsoft.github.io/language-server-protocol/ Language Server Protocol servers>.
    @Language.LSP.Test@ launches your server as a subprocess and allows you to simulate a session
    down to the wire.
    To see examples of it in action, check out <https://github.com/haskell/haskell-ide-engine haskell-ide-engine>,
    <https://github.com/haskell/haskell-language-server haskell-language-server> and
    <https://github.com/digital-asset/ghcide ghcide>.

category:             Testing
abi:                  bdbb8b55d39a7d01d44792ccc93ae400
exposed:              True
exposed-modules:
    Control.Applicative.Combinators from parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav:Control.Applicative.Combinators,
    Language.LSP.Protocol.Capabilities from lsp-types-2.0.1.0-EjYcMkrIVdu9wybjt2x400:Language.LSP.Protocol.Capabilities,
    Language.LSP.Protocol.Message from lsp-types-2.0.1.0-EjYcMkrIVdu9wybjt2x400:Language.LSP.Protocol.Message,
    Language.LSP.Protocol.Types from lsp-types-2.0.1.0-EjYcMkrIVdu9wybjt2x400:Language.LSP.Protocol.Types,
    Language.LSP.Test

hidden-modules:
    Language.LSP.Test.Compat Language.LSP.Test.Decoding
    Language.LSP.Test.Exceptions Language.LSP.Test.Files
    Language.LSP.Test.Parsing Language.LSP.Test.Server
    Language.LSP.Test.Session

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lsp-test-0.15.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lsp-test-0.15.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lsp-test-0.15.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp-test
hs-libraries:         HSlsp-test-0.15.0.1-6xbEqv855SH8gUFKA5jj3l
depends:
    Diff-0.5-2tX1FyxWy6p7M2fvM0xekx Glob-0.10.2-KsmqzAMtUBqD2GDD9ejCew
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk
    aeson-pretty-0.8.10-7oLs7OTWYk9GnMVCodyIc4
    ansi-terminal-1.0.2-HSq0v3QUl8T11Wgx1QLnTe
    async-2.2.5-GGvJE1nOBFYGFw0FXsPFU0 base-4.17.2.1
    bytestring-0.11.5.3 co-log-core-0.3.2.5-1Xm391iqQA3JzPA3ZEW0rk
    conduit-1.3.6.1-YyCKRGvJ9RFx9ccf8Rnd3
    conduit-parse-0.2.1.1-yi6giLqzQ0LD4pCsjh3ej containers-0.6.7
    data-default-0.7.1.3-1SaGr9SWFYZ17MG1fTAOKi directory-1.3.7.1
    exceptions-0.10.5 filepath-1.4.2.2
    lens-5.3.3-1zYcQilqoBK5EhYwkXjOnb
    lsp-2.1.0.0-4wEItkatDyfAFCzTPH6SAN
    lsp-types-2.0.1.0-EjYcMkrIVdu9wybjt2x400 mtl-2.2.2
    parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav process-1.6.18.0
    row-types-1.0.1.2-4x8U1r2LNA9AnBIlVe6fUq
    some-1.0.6-IvwsY91TAMIBuUsSZqAO1V text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unix-2.7.3

haddock-interfaces:   /usr/share/doc/haskell-lsp-test/html/lsp-test.haddock
haddock-html:         /usr/share/doc/haskell-lsp-test/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
